@@ -1,4 +1,4 @@
-/* $Id: dialogs.c 28378 2008-10-23 08:10:03Z stephan $ */
+/* $Id$ */
 /*
  * Copyright (c) 2003,2005 Jasper Huijsmans <jasper@xfce.org>
  * Copyright (c) 2003 Benedikt Meurer <benny@xfce.org>
@@ -40,6 +40,9 @@
 #ifdef HAVE_STRING_H
 #include <string.h>
 #endif
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#endif
 
 #include <glib.h>
 #include <gtk/gtk.h>
@@ -60,14 +63,12 @@
 /* max. length of a message */
 #define MAXMESSAGELEN   2048
 
-/* Darwin does not have a variable named environ
-   but has a function which you can get the environ
-   variable with.  */
-#if defined(__APPLE__) && defined(__MACH__)
-#include <crt_externs.h>
+#ifdef HAVE__NSGETENVIRON
+/* for support under apple/darwin */
 #define environ (*_NSGetEnviron())
-#else
-extern char **environ;
+#elif !HAVE_DECL_ENVIRON
+/* try extern if environ is not defined in unistd.h */
+extern gchar **environ;
 #endif
 
 /* create a header with optional icon (may be NULL) in larger bold font;
@@ -489,6 +490,7 @@ xfce_message_dialog_new_valist(GtkWindow *parent,
     GtkWidget *image;
     gchar *markup = NULL;
     gint default_response = G_MININT;
+    gchar *primary_escaped, *secondary_escaped;
 
     /* create the dialog */
     dialog = gtk_dialog_new ();
@@ -519,18 +521,24 @@ xfce_message_dialog_new_valist(GtkWindow *parent,
 
     if (primary_text && secondary_text)
     {
+        primary_escaped = g_markup_escape_text (primary_text, -1);
+        secondary_escaped = g_markup_escape_text (secondary_text, -1);
         markup = g_strdup_printf ("<span weight='bold' size='large'>%s</span>"
-                                  "\n\n%s", primary_text, secondary_text);
+                                  "\n\n%s", primary_escaped, secondary_escaped);
+        g_free (primary_escaped);
+        g_free (secondary_escaped);
     }
     else if (primary_text)
     {
+        primary_escaped = g_markup_escape_text (primary_text, -1);
         markup =
             g_strdup_printf ("<span weight='bold' size='large'>%s</span>",
-                             primary_text);
+                             primary_escaped);
+        g_free (primary_escaped);
     }
     else
     {
-        markup = g_strdup (secondary_text);
+        markup = g_markup_escape_text (secondary_text, -1);
     }
 
     label = gtk_label_new (NULL);
@@ -573,7 +581,6 @@ xfce_message_dialog_new_valist(GtkWindow *parent,
             if (strcmp (text, XFCE_CUSTOM_PIXBUF_BUTTON) == 0)
             {
                 GdkPixbuf *icon, *scaled;
-                GtkWidget *align, *image, *hbox, *label;
                 gint w, h;
 
                 text = va_arg (args, gchar *);
