@@ -43,24 +43,25 @@ static GtkIconTheme *icon_theme = NULL;
 
 static const gchar *builtin_icon_categories[][XFCE_N_BUILTIN_ICON_CATEGORIES] =
 {
-	{ "xfce-unknown", "gnome-fs-executable", "exec", "emblem-generic", NULL, NULL },
-	{ "xfce-edit", "accessories-text-editor", "gedit-icon", "edit", NULL, NULL },
-	{ "xfce-filemanager", "file-manager", "folder", NULL, NULL, NULL },
-	{ "xfce-utils", "applications-accessories", "gnome-util", "utilities", NULL, NULL },
-	{ "xfce-games", "applications-games", "gnome-joystick", "games", "emblem-fun", NULL },
-	{ "xfce-man", "help-browser", "gnome-help", "help", NULL, NULL },
-	{ "xfce-multimedia", "applications-multimedia", "gnome-multimedia", "multimedia", "emblem-multimedia", NULL, NULL },
-	{ "xfce-internet", "applications-internet", "gnome-globe", "gnome-fs-network", "web-browser", "emblem-web" },
-	{ "xfce-graphics", "applications-graphics", "gnome-graphics", "graphics", NULL, NULL },
-	{ "xfce-printer", "printer", "gnome-dev-printer", NULL, NULL },
-	{ "xfce-schedule", "gnome-month", "productivity", "emblem-documents", NULL, NULL },
-	{ "xfce-office", "applications-office", "gnome-applications", NULL, NULL, NULL, NULL },
-	{ "xfce-sound", "preferences-desktop-sound", "gnome-audio", "sound", NULL, NULL },
-	{ "xfce-terminal", "utilities-terminal", "gnome-terminal", "terminal", NULL, NULL },
-	{ "xfce-devel", "applications-development", "gnome-devel", NULL, NULL },
-	{ "xfce-settings", "preferences-desktop", "gnome-settings", NULL, NULL },
-	{ "xfce-system", "applications-system", "gnome-system", NULL, NULL },
-	{ "xfce-wine", "wine", NULL, NULL, NULL }
+	{ "xfce-unknown", "unknown", "gnome-fs-executable", "exec", "emblem-generic", NULL, NULL },
+	{ "accessories-text-editor", "xfce-edit", "gedit-icon", "edit", NULL, NULL, NULL },
+	{ "system-file-manager", "xfce-filemanager", "file-manager", "folder", NULL, NULL, NULL },
+	{ "applications-utilities", "xfce-utils", "applications-accessories", "gnome-util", "utilities", NULL, NULL },
+	{ "applications-games", "xfce-games", "gnome-joystick", "games", "emblem-fun", NULL, NULL },
+	{ "system-help", "xfce-man", "help-browser", "gnome-help", "help", NULL, NULL },
+	{ "applications-multimedia", "xfce-multimedia", "gnome-multimedia", "multimedia", "emblem-multimedia", NULL, NULL },
+	{ "applications-internet", "xfce-internet", "gnome-globe", "gnome-fs-network", "web-browser", "emblem-web", NULL },
+	{ "applications-graphics", "xfce-graphics", "gnome-graphics", "graphics", NULL, NULL, NULL },
+	{ "printer", "xfce-printer", "gnome-dev-printer", NULL, NULL, NULL, NULL },
+	{ "xfce-schedule", "gnome-month", "productivity", "emblem-documents", "applications-office", NULL, NULL },
+	{ "applications-office", "xfce-office", "gnome-applications", NULL, NULL, NULL, NULL },
+	{ "xfce-sound", "preferences-desktop-sound", "gnome-audio", "sound", "audio-x-generic", NULL, NULL },
+	{ "utilities-terminal", "xfce-terminal", "gnome-terminal", "terminal", NULL, NULL, NULL },
+	{ "applications-development", "xfce-devel", "gnome-devel", NULL, NULL, NULL, NULL },
+	{ "preferences-desktop", "preferences-system", "xfce-settings", "gnome-settings", NULL, NULL, NULL },
+	{ "applications-system", "xfce-system", "gnome-system", NULL, NULL, NULL, NULL },
+	{ "xfce-wine", "wine", NULL, NULL, NULL, NULL, NULL },
+	{ "applications-accessories", "accessories", "xfce-utils", "gnome-util", "utilities", "gnome-applications", NULL, },
 };
 
 /*
@@ -102,7 +103,7 @@ xfce_inline_icon_at_size (const guint8 *data,
 }
 
 static inline void
-ensure_gtk_icon_theme()
+ensure_gtk_icon_theme(void)
 {	
     if(G_UNLIKELY(!icon_theme)) {
         icon_theme = gtk_icon_theme_get_default();
