@@ -1,6 +1,6 @@
-/* $Id: libxfcegui4.h 19319 2006-01-06 22:20:32Z dannym $ */
+/* $Id$ */
 /*-
- * Copyright (c) 2002-2004 The Xfce development team.
+ * Copyright (c) 2002-2006 The Xfce development team.
  * All rights reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -23,7 +23,7 @@
 #define __LIBXFCEGUI4_LIBXFCEGUI4_H__
 
 #include <libxfcegui4/libxfcegui4-config.h>
-
+#include <libxfcegui4/gui-enum-types.h>
 #include <libxfcegui4/dialogs.h>
 #include <libxfcegui4/gtk_style.h>
 #include <libxfcegui4/gtktoxevent.h>
@@ -49,7 +49,9 @@
 #include <libxfcegui4/xfce-filechooser.h>
 #include <libxfcegui4/xfce-gdk-extensions.h>
 #include <libxfcegui4/xfce-gtk-extensions.h>
+#include <libxfcegui4/xfce-heading.h>
 #include <libxfcegui4/xfce-icontheme.h>
+#include <libxfcegui4/xfce-titled-dialog.h>
 #include <libxfcegui4/xfce-widget-helpers.h>
 
 #endif  /* !__LIBXFCEGUI4_LIBXFCEGUI4_H__ */
