@@ -341,7 +341,7 @@ netk_pager_size_request (GtkWidget * widget, GtkRequisition * requisition)
         }
         else
         {
-            int n_spaces, i, w;
+            int i, w;
             NetkScreen *screen;
             PangoLayout *layout;
 
@@ -757,7 +757,7 @@ workspace_at_point (NetkPager * pager,
              * belong to the workspace.
              */
 
-            GtkWidget *widget = GTK_WIDGET (pager);
+            widget = GTK_WIDGET (pager);
 
             if (rect.x == xthickness)
             {
@@ -1309,7 +1309,7 @@ netk_pager_drag_timeout (NetkPager *pager)
 
 static void
 netk_pager_drag_leave (GtkWidget * widget, GdkDragContext * context,
-                       guint time, gpointer data)
+                       guint timestamp, gpointer data)
 {
     NetkPager *pager = NETK_PAGER (widget);
 
@@ -1323,7 +1323,7 @@ netk_pager_drag_leave (GtkWidget * widget, GdkDragContext * context,
 
 static gboolean
 netk_pager_drag_motion (GtkWidget * widget, GdkDragContext * context, gint x,
-                        gint y, guint time, gpointer data)
+                        gint y, guint timestamp, gpointer data)
 {
     NetkPager *pager = NETK_PAGER (widget);
     NetkWorkspace *current_ws, *new_ws;
@@ -1353,7 +1353,7 @@ netk_pager_drag_motion (GtkWidget * widget, GdkDragContext * context, gint x,
         pager->priv->ws_activate = 0;
         pager->priv->ws_to_activate = NULL;
     }
-    gdk_drag_status (context, 0, time);
+    gdk_drag_status (context, 0, timestamp);
 
     return TRUE;
 }
