@@ -239,7 +239,7 @@ static void netk_tasklist_disconnect_screen (NetkTasklist * tasklist);
 static GObjectClass *task_parent_class;
 static GObjectClass *tasklist_parent_class;
 
-GType
+static GType
 netk_task_get_type (void)
 {
     static GType type = G_TYPE_INVALID;
@@ -2121,7 +2121,7 @@ netk_task_motion_timeout (gpointer data)
 
 static void
 netk_task_drag_leave (GtkWidget * widget, GdkDragContext * context,
-                      guint time, NetkTask * task)
+                      guint timestamp, NetkTask * task)
 {
     if (task->button_activate != 0)
     {
@@ -2132,14 +2132,14 @@ netk_task_drag_leave (GtkWidget * widget, GdkDragContext * context,
 
 static gboolean
 netk_task_drag_motion (GtkWidget * widget, GdkDragContext * context, gint x,
-                       gint y, guint time, NetkTask * task)
+                       gint y, guint timestamp, NetkTask * task)
 {
 
     if (task->button_activate == 0 && task->type == NETK_TASK_WINDOW)
         task->button_activate = g_timeout_add (TIMEOUT_ACTIVATE,
                                                netk_task_motion_timeout,
                                                task);
-    gdk_drag_status (context, 0, time);
+    gdk_drag_status (context, 0, timestamp);
 
     return TRUE;
 }
@@ -2436,7 +2436,7 @@ draw_dot (GdkWindow * window, GdkGC * lgc, GdkGC * dgc, int x, int y)
 }
 
 
-gboolean
+static gboolean
 netk_task_class_group_expose (GtkWidget * widget, GdkEventExpose * event,
                               gpointer data)
 {
@@ -2575,3 +2575,60 @@ netk_task_new_from_class_group (NetkTasklist * tasklist,
 
     return task;
 }
+
+NetkScreen*
+netk_tasklist_get_screen(NetkTasklist * tasklist)
+{
+    g_return_val_if_fail (NETK_IS_TASKLIST (tasklist), NULL);
+
+    return tasklist->priv->screen;
+}
+
+NetkTasklistGroupingType
+netk_tasklist_get_grouping(NetkTasklist * tasklist)
+{
+    g_return_val_if_fail (NETK_IS_TASKLIST (tasklist), NETK_TASKLIST_NEVER_GROUP);
+
+    return tasklist->priv->grouping;
+}
+
+gboolean 
+netk_tasklist_get_switch_workspace_on_unminimize(NetkTasklist * tasklist)
+{
+    g_return_val_if_fail (NETK_IS_TASKLIST (tasklist), FALSE);
+
+    return tasklist->priv->switch_workspace_on_unminimize;
+}
+
+gint 
+netk_tasklist_get_grouping_limit(NetkTasklist * tasklist)
+{
+    g_return_val_if_fail (NETK_IS_TASKLIST (tasklist), 0);
+
+    return tasklist->priv->grouping_limit;
+}
+
+gboolean 
+netk_tasklist_get_include_all_workspaces(NetkTasklist * tasklist)
+{
+    g_return_val_if_fail (NETK_IS_TASKLIST (tasklist), FALSE);
+
+    return tasklist->priv->include_all_workspaces;
+}
+
+gboolean 
+netk_tasklist_get_show_label(NetkTasklist * tasklist)
+{
+    g_return_val_if_fail (NETK_IS_TASKLIST (tasklist), FALSE);
+
+    return tasklist->priv->show_label;
+}
+
+GtkReliefStyle 
+netk_tasklist_get_button_relief(NetkTasklist * tasklist)
+{
+    g_return_val_if_fail (NETK_IS_TASKLIST (tasklist), GTK_RELIEF_NONE);
+    
+    return tasklist->priv->relief;
+}
+
