@@ -202,11 +202,13 @@ init(void)
 static void
 remove_startup_timeout (SnLauncherContext* sn_context)
 {
+    GSList* item;
+
     if (startup_timeout_data == NULL) {
         return;
     }
     
-    GSList* item = startup_timeout_data->contexts;
+    item = startup_timeout_data->contexts;
     while (item != NULL) {
       if (item->data == sn_context) {
         sn_launcher_context_unref (sn_context);
